severity = 1
exclude = RequireTidyCode RequirePodSections ProhibitPostfixControls RequireRcsKeywords RequireExplicitPackage RequirePodLinksIncludeText Compatibility::PodMinimumVersion Modules::RequireExplicitInclusion ProhibitDebuggingModules ProhibitEmptyCommas ProhibitFlagComments Editor::RequireEmacsFileVariables Documentation::RequirePODUseEncodingUTF8 CodeLayout::ProhibitHashBarewords  CodeLayout::RequireASCII Miscellanea::ProhibitUselessNoCritic 
include = Moose::ProhibitMultipleWiths Moose::ProhibitNewMethod Moose::RequireCleanNamespace Moose::RequireMakeImmutable
color = 1
verbose = 9

[BuiltinFunctions::ProhibitStringyEval]
allow_includes = 1

[CodeLayout::ProhibitTrailingWhitespace]

[Documentation::PodSpelling]
spell_command = aspell list --lang en_US
stop_words = versionless metadata conformant autovivification

[Subroutines::ProhibitCallsToUndeclaredSubs]
exempt_subs = MooseX::Types::subtype MooseX::Types::where MooseX::Types::as MooseX::Types::ModVersion MooseX::Types::ProviderObject

[Subroutines::ProhibitUnusedPrivateSubroutines]
private_name_regex = _(?!build_)\w

[TestingAndDebugging::RequireUseStrict]
equivalent_modules = Moose

[TestingAndDebugging::RequireUseWarnings]
equivalent_modules = Moose

[Tics::ProhibitLongLines]

base_max = 130
