use strict;
use warnings;

package DZ2 v5.5.7 {

    # ABSTRACT: this is a sample package for testing Dist::Zilla;

    sub main {
        return 1;
    }

    1;
  }

__END__

=head1 NAME

DZ2

=cut
